# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that defines the behavior of the remove
button on the stations window.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

class RemoveButton(object):
	"""
	This class defines the behavior of the "Remove" button.
	"""

	def __init__(self, manager, player):
		"""
		Initialize object.

		@param self: Reference to the RemoveButton instance.
		@type self: An RemoveButton object.

		@param manager: Reference to the Manager instance.
		@type manager: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__init_attributes(manager, player)
		self.__signal_id_1 = manager.connect("destroy", self.__destroy_cb)
		self.__signal_id_2 = self.__button.connect("clicked", self.__clicked_cb)
		self.__signal_id_3 = manager.connect("treeview-sensitivity", self.__treeview_sensitivity_cb)

	def __init_attributes(self, manager, player):
		"""
		Initialize data attributes.

		@param self: Reference to the RemoveButton instance.
		@type self: An RemoveButton object.

		@param manager: Reference to the Manager instance.
		@type manager: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__manager = manager
		self.__player = player
		self.__button = manager.glade.get_widget("RemoveButton")
		self.__signal_id_1 = self.__signal_id_2 = None
		self.__signal_id_3 = self.__signal_id_4 = None
		return

	def __destroy_cb(self, *args):
		"""
		Handles callback when the "destroy" signal is emitted.

		@param self: Reference to the RemoveButton instance.
		@type self: A RemoveButton object.
		"""
		from Striim.utils import delete_attributes, disconnect_signal
		disconnect_signal(self.__signal_id_1, self.__manager)
		disconnect_signal(self.__signal_id_2, self.__button)
		disconnect_signal(self.__signal_id_3, self.__manager)
		self.__button.destroy()
		delete_attributes(self)
		del self
		self = None
		return

	def __clicked_cb(self, *args):
		"""
		Handles callback when the "clicked" signal is emitted.

		@param self: Reference to the RemoveButton instance.
		@type self: An RemoveButton object.
		"""
		self.__manager.emit("delete-selections")
		return False

	def __treeview_sensitivity_cb(self, manager, data):
		"""
		Handles callback when the "treeview-sensitivity" signal is emitted.

		@param self: Reference to the RemoveButton instance.
		@type self: An RemoveButton object.

		@param manager: Reference to the Manager instance.
		@type manager: A Manager object.

		@param data: The sensitivity of the treeview.
		@type data: A Boolean object.
		"""
		self.__button.set_property("sensitive", data)
		return
